#
# spec file for package python-PyAudio
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without  test
Name:           python-PyAudio
Version:        0.2.11
Release:        3.13
Summary:        Python Bindings for PortAudio v19
License:        MIT
URL:            https://people.csail.mit.edu/hubert/pyaudio/
Source:         https://files.pythonhosted.org/packages/source/P/PyAudio/PyAudio-%{version}.tar.gz
# PATCH-FIX-UPSTREAM loopback_required.patch mcepl@suse.com
# Mark tests requiring specific hardware as such
Patch0:         loopback_required.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  portaudio-devel
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module numpy}
BuildRequires:  alsa
%endif
%python_subpackages

%description
PyAudio provides Python bindings for PortAudio v19, the cross-platform audio I/O library.
With PyAudio, you can easily use Python to play and record audio streams on a variety
of platforms (e.g., GNU/Linux, Microsoft Windows, and Mac OS X).

%prep
%setup -q -n PyAudio-%{version}
%autopatch -p1

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%if %{with test}
%check
# report send to hubert@mit.edu
export HW_REQUIRED=1
%pyunittest_arch discover -p '*.py' -v -s tests
%endif

%files %{python_files}
%doc CHANGELOG README
%doc examples/
%{python_sitearch}/_portaudio*.so
%{python_sitearch}/pyaudio.py*
%pycache_only %{python_sitearch}/__pycache__/pyaudio*.py*
%{python_sitearch}/PyAudio-%{version}-py*.egg-info

%changelog
* Mon Feb  7 2022 Matej Cepl <mcepl@suse.com>
- Add loopback_required.patch which allows skipping over tests
  requiring special hardware without pytest. The issue reported
  upstream by email.
* Thu Nov  7 2019 Matej Cepl <mcepl@suse.com>
- Run through spec-cleaner
* Mon Aug 28 2017 toddrme2178@gmail.com
- Update to 0.2.11
  * Fix use-after-free memory issue in callback handler.
  * Fix docstring for get_output_latency().
- Update to 0.2.10
  * Release the GIL during PortAudio I/O calls to avoid potential deadlock.
  * Add a few automated unit tests.
- Update to PyAudio 0.2.9
  * Fix overflow error handling logic for pa_read_stream.
  * Fix IOError arguments.
  * Python library surfaces issues with importing low-level C module.
  * Code formatting update.
  * Updates to examples for Python 3 compatibility.
- Implement single-spec version
- Fix source URL
* Mon Jul 14 2014 toddrme2178@gmail.com
- Update to 0.2.8
  * bug fixes related to the Python GIL and device name encoding.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri Nov  2 2012 prusnak@opensuse.org
- updated to 0.2.7
* Wed Oct  3 2012 mvyskocil@suse.com
- initial packaging of python-PyAudio for openSUSE
